| bbk_dimension | R Documentation |
Retrieve the dimension structure for a given dataflow from the Bundesbank SDMX Web Service.
bbk_dimension(id)
id |
( |
A data.table::data.table() with columns:
id |
The dimension id (e.g., |
position |
The position of the dimension in the series key |
codelist |
The id of the associated codelist |
https://api.statistiken.bundesbank.de/
Other metadata:
banxico_metadata(),
bbk_metadata(),
bcb_currencies(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boi_dimension(),
boi_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
bbk_dimension("BBK_ERX")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.