Skip to contents

Retrieve a single series by its key via the Bundesbank SDMX Web Service.

Usage

bbk_series(key)

Arguments

key

(NULL | character())
The series keys to query.

Value

A data.table::data.table() with the requested data.

Examples

# \donttest{
bbk_series("BBEX3.M.DKK.EUR.BB.AC.A01")
#>            date                       key  value    freq
#>          <Date>                    <char>  <num>  <char>
#>   1: 1999-01-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4359 monthly
#>   2: 1999-02-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4344 monthly
#>   3: 1999-03-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4317 monthly
#>   4: 1999-04-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4323 monthly
#>   5: 1999-05-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4318 monthly
#>  ---                                                    
#> 328: 2026-04-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4716 monthly
#> 329: 2026-05-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4731 monthly
#> 330: 2026-06-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4744 monthly
#> 331: 2026-07-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4752 monthly
#> 332: 2026-08-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4751 monthly
#>                                                                                           title
#>                                                                                          <char>
#>   1: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#>   2: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#>   3: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#>   4: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#>   5: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#>  ---                                                                                           
#> 328: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#> 329: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#> 330: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#> 331: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#> 332: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark / End of month
#>      category   unit unit_mult         last_update
#>        <char> <char>    <char>              <char>
#>   1:     WEDE    DKK       One 2026-08-31 15:57:48
#>   2:     WEDE    DKK       One 2026-08-31 15:57:48
#>   3:     WEDE    DKK       One 2026-08-31 15:57:48
#>   4:     WEDE    DKK       One 2026-08-31 15:57:48
#>   5:     WEDE    DKK       One 2026-08-31 15:57:48
#>  ---                                              
#> 328:     WEDE    DKK       One 2026-08-31 15:57:48
#> 329:     WEDE    DKK       One 2026-08-31 15:57:48
#> 330:     WEDE    DKK       One 2026-08-31 15:57:48
#> 331:     WEDE    DKK       One 2026-08-31 15:57:48
#> 332:     WEDE    DKK       One 2026-08-31 15:57:48
#>                                                                                                                                                   comment
#>                                                                                                                                                    <char>
#>   1: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   2: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   3: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   4: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   5: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>  ---                                                                                                                                                     
#> 328: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 329: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 330: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 331: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 332: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>                            source
#>                            <char>
#>   1: European Central Bank (ECB).
#>   2: European Central Bank (ECB).
#>   3: European Central Bank (ECB).
#>   4: European Central Bank (ECB).
#>   5: European Central Bank (ECB).
#>  ---                             
#> 328: European Central Bank (ECB).
#> 329: European Central Bank (ECB).
#> 330: European Central Bank (ECB).
#> 331: European Central Bank (ECB).
#> 332: European Central Bank (ECB).
bbk_series("BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B")
#>            date                                 key value      freq
#>          <Date>                              <char> <num>    <char>
#>   1: 1999-01-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   2: 1999-04-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   3: 1999-07-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   4: 1999-10-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   5: 2000-01-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>  ---                                                               
#> 105: 2025-01-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.2 quarterly
#> 106: 2025-04-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.3 quarterly
#> 107: 2025-07-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.3 quarterly
#> 108: 2025-10-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   3.9 quarterly
#> 109: 2026-01-01 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   3.7 quarterly
#>                                                                                       title
#>                                                                                      <char>
#>   1: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   2: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   3: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   4: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   5: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>  ---                                                                                       
#> 105: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 106: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 107: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 108: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 109: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>      category   unit unit_mult         last_update comment source
#>        <char> <char>    <char>              <char>  <char> <char>
#>   1:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   2:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   3:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   4:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   5:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>  ---                                                             
#> 105:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 106:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 107:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 108:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 109:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
bbk_series("BBBK11.D.TTA000")
#>             date             key  value   freq
#>           <Date>          <char>  <num> <char>
#>    1: 1998-12-22 BBBK11.D.TTA000 -13688  daily
#>    2: 1999-01-01 BBBK11.D.TTA000  29312  daily
#>    3: 1999-01-08 BBBK11.D.TTA000  27475  daily
#>    4: 1999-01-15 BBBK11.D.TTA000  27475  daily
#>    5: 1999-01-22 BBBK11.D.TTA000  27475  daily
#>   ---                                         
#> 1444: 2026-08-21 BBBK11.D.TTA000 380708  daily
#> 1445: 2026-08-28 BBBK11.D.TTA000 380708  daily
#> 1446: 2026-09-04 BBBK11.D.TTA000 380708  daily
#> 1447: 2026-09-11 BBBK11.D.TTA000 380708  daily
#> 1448: 2026-09-18 BBBK11.D.TTA000 380708  daily
#>                                                              title category
#>                                                             <char>   <char>
#>    1: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    2: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    3: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    4: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    5: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>   ---                                                                      
#> 1444: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1445: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1446: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1447: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1448: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>         unit unit_mult         last_update comment source
#>       <char>    <char>              <char>  <char> <char>
#>    1:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#>    2:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#>    3:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#>    4:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#>    5:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#>   ---                                                    
#> 1444:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#> 1445:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#> 1446:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#> 1447:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
#> 1448:   EURO  Millions 2026-09-24 10:49:00    <NA>   <NA>
# }