| bde_data | R Documentation |
Retrieve time series data from the BdE statistics API.
bde_data(key, time_range = NULL, lang = "en")
key |
( |
time_range |
(
If |
lang |
( |
You can search for the series codes in the BIEST application or in the tables published by the Banco de España.
A data.table::data.table() with the requested data.
https://www.bde.es/webbe/en/estadisticas/recursos/api-estadisticas-bde.html
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_data(),
bcb_expectations(),
bcb_fx_rates(),
bcb_inflation(),
bcb_selic(),
bcb_top5(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boi_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_other_rates(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
bde_data("D_1NBAF472", time_range = "30M")
bde_data(c("DTNPDE2010_P0000P_PS_APU", "DTNSEC2010_S0000P_APU_SUMAMOVIL"), time_range = "MAX")
bde_data("DEEQ.N.ES.W1.S1.S1.T.B.G._Z._Z._Z.EUR._T._X.N.ALL", time_range = 2024)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.