Skip to contents

Retrieve the dimension structure for a given dataset from the BdF Webstat API.

Usage

bdf_dimension(dataset_id, lang = "en", api_key = bdf_key())

Arguments

dataset_id

(character(1))
The id of the dataset to query (e.g., "CONJ2"). See bdf_dataset() for available datasets.

lang

(character(1))
Language to query. Default "en".

api_key

(character(1))
API key to use for the request. Defaults to the value returned by bdf_key(), which reads from the BANQUEDEFRANCE_KEY environment variable.

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "REF_AREA")

position

The position of the dimension in the series key

codelist

The id of the associated codelist

Examples

if (FALSE) { # \dontrun{
bdf_dimension("CONJ2")
} # }