bdp_dimension: Fetch Banco de Portugal (BdP) dimensions

View source: R/bdp.R

bdp_dimensionR Documentation

Fetch Banco de Portugal (BdP) dimensions

Description

Retrieve the list of dimensions for a given domain, or the categories within a single dimension.

Usage

bdp_dimension(domain_id, dimension_id = NULL, lang = "en")

Arguments

domain_id

(integer(1))
The domain ID. Use bdp_domain() to list available domains.

dimension_id

(NULL | integer(1))
Optional dimension ID. If NULL, all dimensions for the domain are returned. If specified, the categories within that dimension are returned.

lang

(character(1))
Language for labels, either "en" or "pt".

Value

A data.table::data.table() with dimensions or categories.

https://bpstat.bportugal.pt/data/docs

See Also

Other metadata: banxico_metadata(), bbk_dimension(), bbk_metadata(), bcb_currencies(), bdf_dimension(), bdp_dataset(), bdp_domain(), bdp_series(), bis_dimension(), bis_metadata(), boi_dimension(), boi_metadata(), boj_metadata(), cnb_dimension(), cnb_indicators(), cnb_snapshots(), cnb_tree(), ecb_dimension(), ecb_metadata(), nob_dimension(), nob_metadata(), onb_dimension(), onb_frequency(), onb_hierarchy(), onb_metadata(), onb_toc(), snb_dimension(), snb_metadata(), snb_toc(), srb_calendar(), srb_series()

Examples



bdp_dimension(54L)



bbk documentation built on Aug. 28, 2026, 5:07 p.m.