Retrieve the dimension structure for a given dataflow from the BIS SDMX Web Service.
Value
A data.table::data.table() with columns:
- id
The dimension id (e.g.,
"FREQ","REF_AREA")- position
The position of the dimension in the series key
- codelist
The id of the associated codelist (e.g.,
"CL_FREQ")
See also
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_metadata(),
boj_metadata(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
srb_calendar(),
srb_series()