Fetch the latest or historical foreign exchange reference rates from the Bank of Canada (BoC).
Arguments
- start_date
(
NULL|Date(1)|character(1))
Start date of the data. DefaultNULL.- end_date
(
NULL|Date(1)|character(1))
End date of the data. DefaultNULL.- limit
(
NULL|integer(1))
Maximum number of records to return. DefaultNULL(all records).- skip
(
NULL|integer(1))
Number of records to skip. DefaultNULL(do not skip any records).
Value
A data.table::data.table() with the exchange rates.
Details
The recorded rates indicate the number of Canadian dollars required to buy a single unit of the foreign currency. New rates are released by the Bank of Canada (BoC) daily at 4:30 pm. The Canada Border Services (CBSA) retrieves these updates between 4:30 pm and 5 pm ET.
BoC provides 23 foreign exchange rates. All other rates are maintained by the CBSA.
Exchange rates from the BoC are updated daily in the system while other exchange rates are updated by the CBSA at set intervals. The updated rates are available for retrieval between 7 pm and 11:59 pm ET.
As BoC publishes exchange rates every business day, it is recommended that exchange rate data be retrieved on a daily basis. This retrieval should occur after 7 pm ET to ensure retrieval of the latest updates.
Examples
# \donttest{
# fetch latest exchange rates
boc_fx_rates()
#> exchange_rate_id rate exchange_rate_effective_timestamp
#> <int> <num> <POSc>
#> 1: 5842497 0.00376 2026-08-24
#> 2: 5842498 0.08595 2026-08-24
#> 3: 5842499 0.00000 2026-08-24
#> 4: 5842500 1.00000 2026-08-24
#> 5: 5842501 0.00000 2026-08-24
#> ---
#> 150: 5842646 0.01645 2026-08-24
#> 151: 5842647 0.00052 2026-08-24
#> 152: 5842648 0.37763 2026-08-24
#> 153: 5842649 0.07333 2026-08-24
#> 154: 5842650 0.00180 2026-08-24
#> exchange_rate_expiry_timestamp exchange_rate_source from_currency
#> <POSc> <char> <char>
#> 1: 2026-08-24 23:59:59 CBSA ZWL
#> 2: 2026-08-24 23:59:59 BoC ZAR
#> 3: 2026-08-24 23:59:59 CBSA SYP
#> 4: 2026-08-24 23:59:59 CBSA SKL
#> 5: 2026-08-24 23:59:59 CBSA XCG
#> ---
#> 150: 2026-08-24 23:59:59 CBSA RUB
#> 151: 2026-08-24 23:59:59 CBSA TZS
#> 152: 2026-08-24 23:59:59 CBSA AED
#> 153: 2026-08-24 23:59:59 CBSA ZMW
#> 154: 2026-08-24 23:59:59 CBSA VES
#> from_currency_csn to_currency to_currency_csn
#> <int> <char> <int>
#> 1: 238 CAD 36
#> 2: 227 CAD 36
#> 3: 188 CAD 36
#> 4: 180 CAD 36
#> 5: 252 CAD 36
#> ---
#> 150: 167 CAD 36
#> 151: 202 CAD 36
#> 152: 1 CAD 36
#> 153: 229 CAD 36
#> 154: 214 CAD 36
# fetch historical exchange rates
boc_fx_rates(start_date = "2021-10-22", end_date = "2021-10-23", limit = 10, skip = 2)
#> exchange_rate_id rate exchange_rate_effective_timestamp
#> <int> <num> <POSc>
#> 1: 5546931 0.193100 2021-10-22
#> 2: 5546932 1.437200 2021-10-22
#> 3: 5546933 0.158900 2021-10-22
#> 4: 5546934 0.016500 2021-10-22
#> 5: 5546935 0.000087 2021-10-22
#> 6: 5546936 0.010850 2021-10-22
#> 7: 5546937 0.060900 2021-10-22
#> 8: 5546938 0.884600 2021-10-22
#> 9: 5546939 0.147900 2021-10-22
#> 10: 5546940 0.312500 2021-10-22
#> exchange_rate_expiry_timestamp exchange_rate_source from_currency
#> <POSc> <char> <char>
#> 1: 2021-10-22 23:59:59 BoC CNY
#> 2: 2021-10-22 23:59:59 BoC EUR
#> 3: 2021-10-22 23:59:59 BoC HKD
#> 4: 2021-10-22 23:59:59 BoC INR
#> 5: 2021-10-22 23:59:59 BoC IDR
#> 6: 2021-10-22 23:59:59 BoC JPY
#> 7: 2021-10-22 23:59:59 BoC MXN
#> 8: 2021-10-22 23:59:59 BoC NZD
#> 9: 2021-10-22 23:59:59 BoC NOK
#> 10: 2021-10-22 23:59:59 BoC PEN
#> from_currency_csn to_currency to_currency_csn
#> <int> <char> <int>
#> 1: 42 CAD 36
#> 2: 66 CAD 36
#> 3: 87 CAD 36
#> 4: 95 CAD 36
#> 5: 92 CAD 36
#> 6: 102 CAD 36
#> 7: 138 CAD 36
#> 8: 150 CAD 36
#> 9: 148 CAD 36
#> 10: 154 CAD 36
# }