Skip to contents

Retrieve the dimension structure for a given dataflow from the Bank of Israel SDMX Web Service.

Usage

boi_dimension(id)

Arguments

id

(character(1))
The id of the data structure definition to query (e.g., "EXR").

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "BASE_CURRENCY")

position

The position of the dimension in the series key

codelist

The id of the associated codelist (e.g., "CL_FREQ")

Examples

# \donttest{
boi_dimension("EXR")
#>                  id position           codelist
#>              <char>    <int>             <char>
#> 1:      SERIES_CODE        1 CL_SERIES_CODE_EXR
#> 2:             FREQ        2            CL_FREQ
#> 3:    BASE_CURRENCY        3        CL_CURRENCY
#> 4: COUNTER_CURRENCY        4        CL_CURRENCY
#> 5:     UNIT_MEASURE        5            CL_UNIT
#> 6:        DATA_TYPE        6   CL_DATA_TYPE_EXR
# }