cache: Get or manage the bbk API cache

cacheR Documentation

Get or manage the bbk API cache

Description

bbk_cache_dir() returns the path where cached API responses are stored. bbk_cache_clear() clears all cached responses.

Usage

bbk_cache_dir()

bbk_cache_clear()

Details

The cache is only used when enabled with options(bbk.cache = TRUE). Cached responses are stored for 1 day by default, but this can be customized with options(bbk.cache_max_age = seconds).

Value

bbk_cache_dir() returns a string with the path to the cache directory.

bbk_cache_clear() is called for its side effect of clearing the cached responses and returns NULL invisibly.

Examples

## Not run: 
# enable caching
options(bbk.cache = TRUE)

# view cache location
bbk_cache_dir()

# clear the cache
bbk_cache_clear()

## End(Not run)

bbk documentation built on Aug. 28, 2026, 5:07 p.m.