cnb_indicators: Fetch Czech National Bank (CNB) ARAD indicators

View source: R/cnb.R

cnb_indicatorsR Documentation

Fetch Czech National Bank (CNB) ARAD indicators

Description

Retrieve the available indicators and their attributes from the CNB ARAD database. Use this to discover indicator identifiers for cnb_data().

Usage

cnb_indicators(
  indicator_id = NULL,
  set_id = NULL,
  base_id = NULL,
  selection_id = NULL,
  lang = "en",
  api_key = cnb_arad_key()
)

Arguments

indicator_id

(NULL | character())
One or more indicator identifiers to retrieve (e.g. "SMV5M603"). Exactly one of indicator_id, set_id, base_id, or selection_id must be provided.

set_id

(NULL | character(1))
A set ("sestava") identifier, returning all of its indicators.

base_id

(NULL | character(1))
A base identifier, returning all of its indicators.

selection_id

(NULL | character(1))
The identifier of a named selection ("My selections") created in your ARAD account.

lang

(character(1))
Language for the textual attributes, either "en" or "cs". Default "en".

api_key

(character(1))
API key to use for the request. Defaults to the value returned by cnb_arad_key(), which reads from the CNB_ARAD_KEY environment variable.

Value

A data.table::data.table() with one row per indicator and columns including indicator_id, indicator_name, frequency_code, frequency_name, unit_mult_code, unit_mult_name, and unit.

https://www.cnb.cz/docs/arad20/dokumentace/arad_rest_api_cs.pdf

See Also

Other metadata: banxico_metadata(), bbk_dimension(), bbk_metadata(), bcb_currencies(), bdf_dimension(), bdp_dataset(), bdp_dimension(), bdp_domain(), bdp_series(), bis_dimension(), bis_metadata(), boi_dimension(), boi_metadata(), boj_metadata(), cnb_dimension(), cnb_snapshots(), cnb_tree(), ecb_dimension(), ecb_metadata(), nob_dimension(), nob_metadata(), onb_dimension(), onb_frequency(), onb_hierarchy(), onb_metadata(), onb_toc(), snb_dimension(), snb_metadata(), snb_toc(), srb_calendar(), srb_series()

Examples

## Not run: 
cnb_indicators(set_id = "1058")

## End(Not run)

bbk documentation built on Aug. 28, 2026, 5:07 p.m.