ecb_dimension: Fetch European Central Bank (ECB) dimensions

View source: R/ecb.R

ecb_dimensionR Documentation

Fetch European Central Bank (ECB) dimensions

Description

Retrieve the dimension structure for a given dataflow from the ECB SDMX Web Service.

Usage

ecb_dimension(id)

Arguments

id

(character(1))
The id of the data structure definition to query (e.g., "ECB_EXR1").

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "CURRENCY")

position

The position of the dimension in the series key

codelist

The id of the associated codelist (e.g., "CL_FREQ")

https://data.ecb.europa.eu/help/api/metadata

See Also

Other metadata: banxico_metadata(), bbk_dimension(), bbk_metadata(), bcb_currencies(), bdf_dimension(), bdp_dataset(), bdp_dimension(), bdp_domain(), bdp_series(), bis_dimension(), bis_metadata(), boi_dimension(), boi_metadata(), boj_metadata(), cnb_dimension(), cnb_indicators(), cnb_snapshots(), cnb_tree(), ecb_metadata(), nob_dimension(), nob_metadata(), onb_dimension(), onb_frequency(), onb_hierarchy(), onb_metadata(), onb_toc(), snb_dimension(), snb_metadata(), snb_toc(), srb_calendar(), srb_series()

Examples



ecb_dimension("ECB_EXR1")



bbk documentation built on Aug. 28, 2026, 5:07 p.m.