Skip to contents

Retrieve the dimension structure for a given data structure from the National Bank of Belgium SDMX Web Service (NBB.Stat).

Usage

nbb_dimension(id)

Arguments

id

(character(1))
The id of the data structure definition to query (e.g., "DSD_EXR").

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "EXR_CURRENCY")

position

The position of the dimension in the series key

codelist

The id of the associated codelist (e.g., "CL_FREQ")

Examples

# \donttest{
nbb_dimension("DSD_EXR")
#>              id position        codelist
#>          <char>    <int>          <char>
#> 1:         FREQ        1         CL_FREQ
#> 2: EXR_CURRENCY        2 CL_EXR_CURRENCY
# }