Skip to contents

Retrieve metadata from the National Bank of Belgium SDMX Web Service (NBB.Stat).

Usage

nbb_metadata(type, id = NULL, lang = "en")

Arguments

type

(character(1))
The type of metadata to query. One of: "datastructure", "dataflow", "codelist", or "concept".

id

(NULL | character(1))
The id to query. Default NULL.

lang

(character(1))
Language for names, one of "en", "fr", or "nl". Default "en".

Value

A data.table::data.table() with the requested metadata.

Examples

# \donttest{
nbb_metadata("dataflow")
#>                     id
#>                 <char>
#>   1:        DF_AFCSURV
#>   2: DF_AFCSURV_CREDIT
#>   3:   DF_AGREED_WAGES
#>   4:          DF_AMOLO
#>   5:        DF_AMPORTS
#>  ---                  
#> 191:       DF_TREASURY
#> 192:       DF_TREASVAR
#> 193:         DF_UCIDEV
#> 194:   DF_UNEMPLOYMENT
#> 195:  DF_UNEMPLOY_RATE
#>                                                                                          name
#>                                                                                        <char>
#>   1:                               Quarterly survey on the assessment of financing conditions
#>   2: Quarterly survey on the assessment of financing conditions: Credit constraint perception
#>   3:                                                                Collectively agreed wages
#>   4:                                                       Outstanding amount of linear bonds
#>   5:                                                                              Ports study
#>  ---                                                                                         
#> 191:                                                                                 Treasury
#> 192:              Nominal variation of the net debt and net financial balance of the Treasury
#> 193:                                                                     Developments of UCIs
#> 194:                                         Number of unemployed job-seekers - unemployement
#> 195:                                                             Harmonised unemployment rate
nbb_metadata("datastructure", "DSD_EXR")
#>         id    name
#>     <char>  <char>
#> 1: DSD_EXR EXR DSD
nbb_metadata("codelist", "CL_EXR_CURRENCY")
#>                 id     name
#>             <char>   <char>
#> 1: CL_EXR_CURRENCY Currency
nbb_metadata("dataflow", "DF_EXR", lang = "fr")
#>        id                                                                  name
#>    <char>                                                                <char>
#> 1: DF_EXR Cours de change de référence de l'euro en unités de monnaie nationale
# }