Skip to contents

Retrieve the dimension structure for a given dataflow from the Norges Bank SDMX Web Service.

Usage

nob_dimension(id)

Arguments

id

(character(1))
The id of the data structure definition to query (e.g., "NB_EXR").

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "BASE_CUR")

position

The position of the dimension in the series key

codelist

The id of the associated codelist (e.g., "CL_FREQ")

Examples

# \donttest{
nob_dimension("DSD_EXR")
#>           id position    codelist
#>       <char>    <int>      <char>
#> 1:      FREQ        1     CL_FREQ
#> 2:  BASE_CUR        2 CL_CURRENCY
#> 3: QUOTE_CUR        3 CL_CURRENCY
#> 4:     TENOR        4    CL_TENOR
# }