Retrieve the dimension structure for a given dataflow from the Bundesbank SDMX Web Service.
Value
A data.table::data.table() with columns:
- id
The dimension id (e.g.,
"BBK_STD_FREQ","BBK_STD_AREA")- position
The position of the dimension in the series key
- codelist
The id of the associated codelist
Examples
# \donttest{
bbk_dimension("BBK_ERX")
#> id position codelist
#> <char> <int> <char>
#> 1: BBK_STD_FREQ 1 CL_BBK_STD_FREQ
#> 2: BBK_STD_CURRENCY 2 CL_BBK_STD_CURRENCY
#> 3: BBK_ERX_PARTNER_CURRENCY 3 CL_BBK_STD_CURRENCY
#> 4: BBK_ERX_SERIES_TYPE 4 CL_BBK_ERX_SERIES_TYPE
#> 5: BBK_ERX_RATE_TYPE 5 CL_BBK_ERX_RATE_TYPE
#> 6: BBK_ERX_SUFFIX 6 CL_BBK_ERX_SUFFIX
# }