Skip to contents

Retrieve a single series by its key via the Bundesbank SDMX Web Service.

Usage

bbk_series(key)

Arguments

key

(NULL | character())
The series keys to query.

Value

A data.table::data.table() with the requested data.

Examples

# \donttest{
bbk_series("BBEX3.M.DKK.EUR.BB.AC.A01")
#>            date                       key  value    freq
#>          <Date>                    <char>  <num>  <char>
#>   1: 1999-01-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4359 monthly
#>   2: 1999-02-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4344 monthly
#>   3: 1999-03-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4317 monthly
#>   4: 1999-04-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4323 monthly
#>   5: 1999-05-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4318 monthly
#>  ---                                                    
#> 327: 2026-03-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4730 monthly
#> 328: 2026-04-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4716 monthly
#> 329: 2026-05-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4731 monthly
#> 330: 2026-06-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4744 monthly
#> 331: 2026-07-01 BBEX3.M.DKK.EUR.BB.AC.A01 7.4752 monthly
#>                                                                            title
#>                                                                           <char>
#>   1: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#>   2: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#>   3: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#>   4: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#>   5: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#>  ---                                                                            
#> 327: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#> 328: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#> 329: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#> 330: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#> 331: Euro foreign exchange reference rate of the ECB / EUR 1 = DKK ... / Denmark
#>      category   unit unit_mult         last_update
#>        <char> <char>    <char>              <char>
#>   1:     WEDE   <NA>       One 2026-07-31 16:08:28
#>   2:     WEDE   <NA>       One 2026-07-31 16:08:28
#>   3:     WEDE   <NA>       One 2026-07-31 16:08:28
#>   4:     WEDE   <NA>       One 2026-07-31 16:08:28
#>   5:     WEDE   <NA>       One 2026-07-31 16:08:28
#>  ---                                              
#> 327:     WEDE   <NA>       One 2026-07-31 16:08:28
#> 328:     WEDE   <NA>       One 2026-07-31 16:08:28
#> 329:     WEDE   <NA>       One 2026-07-31 16:08:28
#> 330:     WEDE   <NA>       One 2026-07-31 16:08:28
#> 331:     WEDE   <NA>       One 2026-07-31 16:08:28
#>                                                                                                                                                   comment
#>                                                                                                                                                    <char>
#>   1: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   2: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   3: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   4: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>   5: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>  ---                                                                                                                                                     
#> 327: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 328: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 329: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 330: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#> 331: The ECB publishes daily euro foreign exchange reference rates, which are calculated on the basis of the concertation between central banks at 14.15.
#>                            source
#>                            <char>
#>   1: European Central Bank (ECB).
#>   2: European Central Bank (ECB).
#>   3: European Central Bank (ECB).
#>   4: European Central Bank (ECB).
#>   5: European Central Bank (ECB).
#>  ---                             
#> 327: European Central Bank (ECB).
#> 328: European Central Bank (ECB).
#> 329: European Central Bank (ECB).
#> 330: European Central Bank (ECB).
#> 331: European Central Bank (ECB).
bbk_series("BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B")
#>         date                                 key value      freq
#>       <char>                              <char> <num>    <char>
#>   1: 1999-Q3 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   2: 1999-Q4 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   3: 2000-Q1 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   4: 2000-Q2 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>   5: 2000-Q3 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.4 quarterly
#>  ---                                                            
#> 103: 2025-Q1 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.2 quarterly
#> 104: 2025-Q2 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.3 quarterly
#> 105: 2025-Q3 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   4.3 quarterly
#> 106: 2025-Q4 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   3.9 quarterly
#> 107: 2026-Q1 BBAF3.Q.F41.S121.DE.S1.W0.LE.N._X.B   3.7 quarterly
#>                                                                                       title
#>                                                                                      <char>
#>   1: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   2: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   3: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   4: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>   5: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>  ---                                                                                       
#> 103: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 104: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 105: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 106: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#> 107: Short-term loans Creditor: Central bank (Germany) / Debtor: All sectors (World) Stocks
#>      category   unit unit_mult         last_update comment source
#>        <char> <char>    <char>              <char>  <char> <char>
#>   1:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   2:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   3:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   4:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>   5:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#>  ---                                                             
#> 103:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 104:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 105:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 106:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
#> 107:     FIF2   <NA>  Billions 2026-07-15 11:11:23    <NA>   <NA>
bbk_series("BBBK11.D.TTA000")
#>             date             key  value   freq
#>           <Date>          <char>  <num> <char>
#>    1: 1999-01-01 BBBK11.D.TTA000  29312  daily
#>    2: 1999-01-08 BBBK11.D.TTA000  27475  daily
#>    3: 1999-01-15 BBBK11.D.TTA000  27475  daily
#>    4: 1999-01-22 BBBK11.D.TTA000  27475  daily
#>    5: 1999-01-29 BBBK11.D.TTA000  27475  daily
#>   ---                                         
#> 1437: 2026-07-10 BBBK11.D.TTA000 380732  daily
#> 1438: 2026-07-17 BBBK11.D.TTA000 380732  daily
#> 1439: 2026-07-24 BBBK11.D.TTA000 380732  daily
#> 1440: 2026-07-31 BBBK11.D.TTA000 380732  daily
#> 1441: 2026-08-07 BBBK11.D.TTA000 380732  daily
#>                                                              title category
#>                                                             <char>   <char>
#>    1: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    2: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    3: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    4: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>    5: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>   ---                                                                      
#> 1437: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1438: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1439: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1440: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#> 1441: Gold and gold receivables / unadjusted / Deutsche Bundesbank   BABA11
#>         unit unit_mult         last_update comment source
#>       <char>    <char>              <char>  <char> <char>
#>    1:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#>    2:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#>    3:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#>    4:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#>    5:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#>   ---                                                    
#> 1437:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#> 1438:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#> 1439:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#> 1440:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
#> 1441:   <NA>  Millions 2026-08-13 10:38:17    <NA>   <NA>
# }