| bcb_data | R Documentation |
Retrieve time series data from the Banco Central do Brasil SGS (Sistema Gerenciador de Séries Temporais) API.
bcb_data(series, start_date = NULL, end_date = NULL)
series |
( |
start_date |
( |
end_date |
( |
Daily series require a date range and the API limits the query window to at most 10 years; supply
start_date (and optionally end_date) when querying such series.
A data.table::data.table() with the requested data.
https://dadosabertos.bcb.gov.br/
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_expectations(),
bcb_fx_rates(),
bcb_inflation(),
bcb_selic(),
bcb_top5(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boi_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_other_rates(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# fetch USD/BRL exchange rate
bcb_data(1, start_date = "2024-01-01", end_date = "2024-01-31")
# fetch the Selic target rate
bcb_data(432, start_date = "2024-01-01", end_date = "2024-01-31")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.