| bcb_expectations | R Documentation |
Retrieve market expectations from the Banco Central do Brasil Focus survey (Relatório Focus) via the Olinda API. Each row is the summary of survey responses collected on a given date for a future reference period.
bcb_expectations(
type = "annual",
indicator = NULL,
start_date = NULL,
end_date = NULL
)
type |
( |
indicator |
( |
start_date |
( |
end_date |
( |
Querying without a filter returns the full history, which is large; supplying indicator and/or a
date range is recommended.
A data.table::data.table() with columns date, indicator, detail, reference,
mean, median, sd, min, max, respondents, and base.
https://dadosabertos.bcb.gov.br/
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_data(),
bcb_fx_rates(),
bcb_inflation(),
bcb_selic(),
bcb_top5(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boi_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_other_rates(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# annual IPCA inflation expectations
bcb_expectations("annual", "IPCA", start_date = "2024-01-01", end_date = "2024-01-31")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.