Retrieve market expectations for the Selic target rate from the Banco Central do Brasil Focus survey (Relatório Focus) via the Olinda API. Each row summarises the forecasts collected on a given survey date for a future COPOM meeting.
Arguments
- start_date
(
NULL|Date(1)|character(1))
Start of the survey date range (e.g.,"2024-01-01"). IfNULL, no lower bound is applied. DefaultNULL.- end_date
(
NULL|Date(1)|character(1))
End of the survey date range, in the same format as start_date. IfNULL, no upper bound is applied. DefaultNULL.
Value
A data.table::data.table() with columns date, meeting, mean, median, sd,
min, max, respondents, and base. The meeting column identifies the COPOM meeting the
forecast refers to (e.g. "R3/2028").
See also
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_data(),
bcb_expectations(),
bcb_fx_rates(),
bcb_inflation(),
bcb_top5(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_other_rates(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
Examples
# \donttest{
bcb_selic(start_date = "2024-01-01", end_date = "2024-01-31")
#> date meeting mean median sd min max respondents base
#> <Date> <char> <num> <num> <num> <num> <num> <int> <int>
#> 1: 2024-01-02 R1/2024 11.2500 11.25 0.0000 11.25 11.25 30 1
#> 2: 2024-01-02 R1/2024 11.2390 11.25 0.0669 10.75 11.25 136 0
#> 3: 2024-01-02 R2/2024 10.7417 10.75 0.0449 10.50 10.75 30 1
#> 4: 2024-01-02 R2/2024 10.7188 10.75 0.1069 10.25 11.00 136 0
#> 5: 2024-01-02 R3/2024 10.2500 10.25 0.1291 9.75 10.50 30 1
#> ---
#> 700: 2024-01-31 R6/2025 8.6100 8.50 0.5681 7.00 10.00 129 0
#> 701: 2024-01-31 R7/2025 8.5417 8.50 0.5889 7.00 10.00 78 1
#> 702: 2024-01-31 R7/2025 8.5870 8.50 0.5737 7.00 10.00 129 0
#> 703: 2024-01-31 R8/2025 8.5549 8.50 0.6649 7.00 10.50 82 1
#> 704: 2024-01-31 R8/2025 8.5702 8.50 0.6175 7.00 10.50 139 0
# }