| bcb_top5 | R Documentation |
Retrieve the Top-5 market expectations from the Banco Central do Brasil Focus survey (Relatório Focus) via the Olinda API. The Top-5 ranking summarises the forecasts of the institutions with the most accurate projections for a given indicator.
bcb_top5(type = "annual", indicator = NULL, start_date = NULL, end_date = NULL)
type |
( |
indicator |
( |
start_date |
( |
end_date |
( |
A data.table::data.table() with columns date, indicator, type_calc, reference,
mean, median, sd, min, and max. The type_calc column holds the ranking horizon
("C" short, "M" medium, or "L" long term). For type = "selic" the reference column
holds the COPOM meeting (e.g. "R4/2026").
https://dadosabertos.bcb.gov.br/
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_data(),
bcb_expectations(),
bcb_fx_rates(),
bcb_inflation(),
bcb_selic(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boi_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_other_rates(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# annual Top-5 IPCA inflation expectations
bcb_top5("annual", "IPCA", start_date = "2024-01-01", end_date = "2024-01-31")
# Top-5 Selic target rate expectations
bcb_top5("selic", start_date = "2024-01-01", end_date = "2024-01-31")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.