Retrieve the dimension structure for a given dataset from the BdF Webstat API.
Arguments
- dataset_id
(
character(1))
The id of the dataset to query (e.g.,"CONJ2"). Seebdf_dataset()for available datasets.- lang
(
character(1))
Language to query. Default"en".- api_key
(
character(1))
API key to use for the request. Defaults to the value returned bybdf_key(), which reads from theBANQUEDEFRANCE_KEYenvironment variable.
Value
A data.table::data.table() with columns:
- id
The dimension id (e.g.,
"FREQ","REF_AREA")- position
The position of the dimension in the series key
- codelist
The id of the associated codelist
See also
Other metadata:
bbk_dimension(),
bbk_metadata(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()