Learn R Programming

bbk (version 0.11.0)

bdf_dimension: Fetch Banque de France (BdF) dimensions

Description

Retrieve the dimension structure for a given dataset from the BdF Webstat API.

Usage

bdf_dimension(dataset_id, lang = "en", api_key = bdf_key())

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "REF_AREA")

position

The position of the dimension in the series key

codelist

The id of the associated codelist

Arguments

dataset_id

(character(1))
The id of the dataset to query (e.g., "CONJ2"). See bdf_dataset() for available datasets.

lang

(character(1))
Language to query. Default "en".

api_key

(character(1))
API key to use for the request. Defaults to the value returned by bdf_key(), which reads from the BANQUEDEFRANCE_KEY environment variable.

See Also

Other metadata: bbk_dimension(), bbk_metadata(), bdp_dataset(), bdp_dimension(), bdp_domain(), bdp_series(), bis_dimension(), bis_metadata(), boj_metadata(), cnb_dimension(), cnb_indicators(), cnb_snapshots(), cnb_tree(), ecb_dimension(), ecb_metadata(), nob_dimension(), nob_metadata(), onb_dimension(), onb_frequency(), onb_hierarchy(), onb_metadata(), onb_toc(), snb_dimension(), snb_metadata(), snb_toc(), srb_calendar(), srb_series()

Examples

Run this code
if (FALSE) {
bdf_dimension("CONJ2")
}

Run the code above in your browser using DataLab