Retrieve the list of dimensions for a given domain, or the categories within a single dimension.
Arguments
- domain_id
(
integer(1))
The domain ID. Usebdp_domain()to list available domains.- dimension_id
(
NULL|integer(1))
Optional dimension ID. IfNULL, all dimensions for the domain are returned. If specified, the categories within that dimension are returned.- lang
(
character(1))
Language for labels, either"en"or"pt".
Value
A data.table::data.table() with dimensions or categories.
See also
Other metadata:
banxico_metadata(),
bbk_dimension(),
bbk_metadata(),
bcb_currencies(),
bdf_dimension(),
bdp_dataset(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
Examples
# \donttest{
bdp_dimension(54L)
#> id label
#> <int> <char>
#> 1: 2 Expenditure aggregates
#> 2: 5 Adjustments and temporary effects
#> 3: 63 Reference territory
#> 4: 59 Counterparty territory
#> 5: 19 Flows, stocks and prices
#> 6: 40 Periodicity
#> 7: 18 Source
#> 8: 70 Unit of measure
#> 9: 28 Valuation method
#> 10: 29 Metrics
#> description
#> <char>
#> 1: Expenditure aggregates allow the grouping of expenditure items according to certain homogeneity criteria. That is the case of the GDP breakdown according to the expenditure approach
#> 2: Adjustments and temporary effects are a set of procedures on elementary statistical information that enables, the adjustment from seasonal effects, working days, among other effects, in accordance with methodologies that allow data consistency
#> 3: Reference territory corresponds to the geographical and / or economic area of the presented statistics
#> 4: Counterparty territory corresponds to the geographical and / or economic area of the opposite part of the presented statistics
#> 5: Flows and stocks refer to economic events that occur, respectively, over a given time period and at a given moment in time, while prices refer to the economic value of a statistical variable in a given period
#> 6: The periodicity sets the frequency of the statistical data
#> 7: The source indicates the entity responsible for the statistical information
#> 8: The unit of measure indicates what is the unit and the power by which the statistic is expressed
#> 9: The valuation method defines the evaluation criteria followed in the collection of the statistical results
#> 10: The metrics translates the calculation method applied in the collection of statistical data
# }