Skip to contents

Retrieve the dimension structure for a given dataflow from the BIS SDMX Web Service.

Usage

bis_dimension(id)

Arguments

id

(character(1))
The id of the data structure definition to query (e.g., "BIS_CBPOL").

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "REF_AREA")

position

The position of the dimension in the series key

codelist

The id of the associated codelist (e.g., "CL_FREQ")

Examples

# \donttest{
bis_dimension("BIS_CBPOL")
#>          id position           codelist
#>      <char>    <int>             <char>
#> 1:     FREQ        1            CL_FREQ
#> 2: REF_AREA        2 CL_BIS_GL_REF_AREA
# }