Learn R Programming

bbk (version 0.11.0)

bis_dimension: Fetch Bank for International Settlements (BIS) dimensions

Description

Retrieve the dimension structure for a given dataflow from the BIS SDMX Web Service.

Usage

bis_dimension(id)

Value

A data.table::data.table() with columns:

id

The dimension id (e.g., "FREQ", "REF_AREA")

position

The position of the dimension in the series key

codelist

The id of the associated codelist (e.g., "CL_FREQ")

Arguments

id

(character(1))
The id of the data structure definition to query (e.g., "BIS_CBPOL").

See Also

Other metadata: bbk_dimension(), bbk_metadata(), bdf_dimension(), bdp_dataset(), bdp_dimension(), bdp_domain(), bdp_series(), bis_metadata(), boj_metadata(), cnb_dimension(), cnb_indicators(), cnb_snapshots(), cnb_tree(), ecb_dimension(), ecb_metadata(), nob_dimension(), nob_metadata(), onb_dimension(), onb_frequency(), onb_hierarchy(), onb_metadata(), onb_toc(), snb_dimension(), snb_metadata(), snb_toc(), srb_calendar(), srb_series()

Examples

Run this code
# \donttest{
bis_dimension("BIS_CBPOL")
# }

Run the code above in your browser using DataLab