| cache | R Documentation |
bbk_cache_dir() returns the path where cached API responses are stored.
bbk_cache_clear() clears all cached responses.
bbk_cache_dir()
bbk_cache_clear()
The cache is only used when enabled with options(bbk.cache = TRUE).
Cached responses are stored for 1 day by default, but this can be customized with
options(bbk.cache_max_age = seconds).
bbk_cache_dir() returns a string with the path to the cache directory.
bbk_cache_clear() is called for its side effect of clearing the cached
responses and returns NULL invisibly.
## Not run:
# enable caching
options(bbk.cache = TRUE)
# view cache location
bbk_cache_dir()
# clear the cache
bbk_cache_clear()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.