bbk_cache_dir() returns the path where cached API responses are stored.
bbk_cache_clear() clears all cached responses.
Usage
bbk_cache_dir()
bbk_cache_clear()
Arguments
Details
The cache is only used when enabled with options(bbk.cache = TRUE).
Cached responses are stored for 1 day by default, but this can be customized with
options(bbk.cache_max_age = seconds).