Learn R Programming

bbk (version 0.11.0)

cnb_czeonia: Fetch Czech National Bank (CNB) CZEONIA rates

Description

Retrieve the Czech Overnight Index Average (CZEONIA) reference rate from the CNB API.

Usage

cnb_czeonia(date = NULL, year = NULL)

Value

A data.table::data.table() with the requested rates. The czeonia column holds the rate in percent and volume the trading volume in millions of Czech koruna.

Arguments

date

(NULL | character(1) | Date(1))
The date to query. If NULL, the latest available rates are returned. Mutually exclusive with year. Default NULL.

year

(NULL | integer(1))
A calendar year, returning rates for every working day of that year. Mutually exclusive with date. Default NULL.

See Also

Other data: bbk_data(), bbk_series(), bde_data(), bde_latest(), bdf_codelist(), bdf_data(), bdf_dataset(), bdp_data(), bis_data(), boc_data(), boe_data(), boj_data(), cnb_data(), cnb_fx_other_rates(), cnb_fx_rates(), cnb_pribor(), ecb_data(), nbp_fx_rates(), nbp_gold(), nob_data(), onb_data(), snb_data(), srb_cross_rates(), srb_data()

Examples

Run this code
# \donttest{
# latest rate
cnb_czeonia()

# all rates for a given year
cnb_czeonia(year = 2024L)
# }

Run the code above in your browser using DataLab