| cnb_fx_other_rates | R Documentation |
Retrieve the monthly exchange rate fixing for less commonly traded ("other") currencies from the
CNB API. These currencies are not part of the daily fixing returned by cnb_fx_rates().
cnb_fx_other_rates(year_month = NULL, year = NULL, lang = "EN")
year_month |
( |
year |
( |
lang |
( |
A data.table::data.table() with the requested exchange rates. The rate is the amount
of Czech koruna per amount units of the foreign currency.
https://api.cnb.cz/cnbapi/swagger-ui.html
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_data(),
bcb_expectations(),
bcb_fx_rates(),
bcb_inflation(),
bcb_selic(),
bcb_top5(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boi_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
# a specific month
cnb_fx_other_rates(year_month = "2024-01")
# all months of a given year
cnb_fx_other_rates(year = 2024L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.