Retrieve the central bank exchange rate fixing (Czech koruna against foreign currencies) from the CNB API.
Arguments
- date
(
NULL|character(1)|Date(1))
The date to query, returning rates for all currencies on that day. IfNULL, the latest available fixing is returned. Mutually exclusive withyear. DefaultNULL.- year
(
NULL|integer(1))
A calendar year, returning rates for all currencies on every working day of that year. Mutually exclusive withdate. DefaultNULL.- lang
(
character(1))
Language for the country and currency names, either"EN"or"CZ". Default"EN".
Value
A data.table::data.table() with the requested exchange rates. The rate is the amount
of Czech koruna per amount units of the foreign currency.
See also
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_data(),
bcb_expectations(),
bcb_fx_rates(),
bcb_inflation(),
bcb_selic(),
bcb_top5(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boi_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_other_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
Examples
# \donttest{
# latest fixing for all currencies
cnb_fx_rates()
#> date currency_code currency country amount rate
#> <Date> <char> <char> <char> <int> <num>
#> 1: 2026-09-11 AUD dollar Australia 1 15.010
#> 2: 2026-09-11 BRL real Brazil 1 4.098
#> 3: 2026-09-11 CAD dollar Canada 1 15.102
#> 4: 2026-09-11 CNY renminbi China 1 3.120
#> 5: 2026-09-11 DKK krone Denmark 1 3.246
#> 6: 2026-09-11 EUR euro EMU 1 24.260
#> 7: 2026-09-11 HKD dollar Hongkong 1 2.669
#> 8: 2026-09-11 HUF forint Hungary 100 6.661
#> 9: 2026-09-11 ISK krona Iceland 100 17.378
#> 10: 2026-09-11 XDR SDR IMF 1 28.743
#> 11: 2026-09-11 INR rupee India 100 21.901
#> 12: 2026-09-11 IDR rupiah Indonesia 1000 1.190
#> 13: 2026-09-11 ILS new shekel Israel 1 6.870
#> 14: 2026-09-11 JPY yen Japan 100 13.590
#> 15: 2026-09-11 MYR ringgit Malaysia 1 5.141
#> 16: 2026-09-11 MXN peso Mexico 1 1.233
#> 17: 2026-09-11 NZD dollar New Zealand 1 12.182
#> 18: 2026-09-11 NOK krone Norway 1 2.250
#> 19: 2026-09-11 PHP peso Philippines 100 33.415
#> 20: 2026-09-11 PLN zloty Poland 1 5.609
#> 21: 2026-09-11 RON leu Romania 1 4.617
#> 22: 2026-09-11 SGD dollar Singapore 1 16.506
#> 23: 2026-09-11 ZAR rand South Africa 1 1.295
#> 24: 2026-09-11 KRW won South Korea 100 1.558
#> 25: 2026-09-11 SEK krona Sweden 1 2.159
#> 26: 2026-09-11 CHF franc Switzerland 1 25.675
#> 27: 2026-09-11 THB baht Thailand 100 63.301
#> 28: 2026-09-11 TRY lira Turkey 100 43.130
#> 29: 2026-09-11 GBP pound United Kingdom 1 28.276
#> 30: 2026-09-11 USD dollar USA 1 20.927
#> date currency_code currency country amount rate
#> <Date> <char> <char> <char> <int> <num>
# all fixings for a given year
cnb_fx_rates(year = 2024L)
#> date currency_code amount rate
#> <Date> <char> <int> <num>
#> 1: 2024-01-02 AUD 1 15.278
#> 2: 2024-01-02 BGN 1 12.621
#> 3: 2024-01-02 BRL 1 4.609
#> 4: 2024-01-02 CAD 1 16.938
#> 5: 2024-01-02 CHF 1 26.524
#> ---
#> 7808: 2024-12-31 THB 100 70.618
#> 7809: 2024-12-31 TRY 100 68.539
#> 7810: 2024-12-31 USD 1 24.237
#> 7811: 2024-12-31 XDR 1 31.609
#> 7812: 2024-12-31 ZAR 1 1.284
# }