Retrieve the central bank exchange rate fixing (Czech koruna against foreign currencies) from the CNB API.
Arguments
- date
(
NULL|character(1)|Date(1))
The date to query, returning rates for all currencies on that day. IfNULL, the latest available fixing is returned. Mutually exclusive withyear. DefaultNULL.- year
(
NULL|integer(1))
A calendar year, returning rates for all currencies on every working day of that year. Mutually exclusive withdate. DefaultNULL.- lang
(
character(1))
Language for the country and currency names, either"EN"or"CZ". Default"EN".
Value
A data.table::data.table() with the requested exchange rates. The rate is the amount
of Czech koruna per amount units of the foreign currency.
See also
Other data:
banxico_data(),
bbk_data(),
bbk_series(),
bcb_data(),
bcb_expectations(),
bcb_fx_rates(),
bcb_inflation(),
bcb_selic(),
bcb_top5(),
bde_data(),
bde_latest(),
bdf_codelist(),
bdf_data(),
bdf_dataset(),
bdp_data(),
bis_data(),
boc_data(),
boe_data(),
boj_data(),
cnb_czeonia(),
cnb_data(),
cnb_fx_other_rates(),
cnb_pribor(),
ecb_data(),
nbp_fx_rates(),
nbp_gold(),
nob_data(),
onb_data(),
snb_data(),
srb_cross_rates(),
srb_data()
Examples
# \donttest{
# latest fixing for all currencies
cnb_fx_rates()
#> date currency_code currency country amount rate
#> <Date> <char> <char> <char> <int> <num>
#> 1: 2026-06-18 AUD dollar Australia 1 14.779
#> 2: 2026-06-18 BRL real Brazil 1 4.099
#> 3: 2026-06-18 CAD dollar Canada 1 14.926
#> 4: 2026-06-18 CNY renminbi China 1 3.113
#> 5: 2026-06-18 DKK krone Denmark 1 3.234
#> 6: 2026-06-18 EUR euro EMU 1 24.175
#> 7: 2026-06-18 HKD dollar Hongkong 1 2.689
#> 8: 2026-06-18 HUF forint Hungary 100 6.860
#> 9: 2026-06-18 ISK krona Iceland 100 16.742
#> 10: 2026-06-18 XDR SDR IMF 1 28.806
#> 11: 2026-06-18 INR rupee India 100 22.343
#> 12: 2026-06-18 IDR rupiah Indonesia 1000 1.190
#> 13: 2026-06-18 ILS new shekel Israel 1 7.168
#> 14: 2026-06-18 JPY yen Japan 100 13.099
#> 15: 2026-06-18 MYR ringgit Malaysia 1 5.119
#> 16: 2026-06-18 MXN peso Mexico 1 1.214
#> 17: 2026-06-18 NZD dollar New Zealand 1 12.158
#> 18: 2026-06-18 NOK krone Norway 1 2.177
#> 19: 2026-06-18 PHP peso Philippines 100 34.771
#> 20: 2026-06-18 PLN zloty Poland 1 5.679
#> 21: 2026-06-18 RON leu Romania 1 4.614
#> 22: 2026-06-18 SGD dollar Singapore 1 16.335
#> 23: 2026-06-18 ZAR rand South Africa 1 1.285
#> 24: 2026-06-18 KRW won South Korea 100 1.370
#> 25: 2026-06-18 SEK krona Sweden 1 2.201
#> 26: 2026-06-18 CHF franc Switzerland 1 26.226
#> 27: 2026-06-18 THB baht Thailand 100 64.325
#> 28: 2026-06-18 TRY lira Turkey 100 45.382
#> 29: 2026-06-18 GBP pound United Kingdom 1 27.895
#> 30: 2026-06-18 USD dollar USA 1 21.078
#> date currency_code currency country amount rate
#> <Date> <char> <char> <char> <int> <num>
# all fixings for a given year
cnb_fx_rates(year = 2024L)
#> date currency_code amount rate
#> <Date> <char> <int> <num>
#> 1: 2024-01-02 AUD 1 15.278
#> 2: 2024-01-02 BGN 1 12.621
#> 3: 2024-01-02 BRL 1 4.609
#> 4: 2024-01-02 CAD 1 16.938
#> 5: 2024-01-02 CHF 1 26.524
#> ---
#> 7808: 2024-12-31 THB 100 70.618
#> 7809: 2024-12-31 TRY 100 68.539
#> 7810: 2024-12-31 USD 1 24.237
#> 7811: 2024-12-31 XDR 1 31.609
#> 7812: 2024-12-31 ZAR 1 1.284
# }