cnb_fx_rates: Fetch Czech National Bank (CNB) exchange rates

View source: R/cnb.R

cnb_fx_ratesR Documentation

Fetch Czech National Bank (CNB) exchange rates

Description

Retrieve the central bank exchange rate fixing (Czech koruna against foreign currencies) from the CNB API.

Usage

cnb_fx_rates(date = NULL, year = NULL, lang = "EN")

Arguments

date

(NULL | character(1) | Date(1))
The date to query, returning rates for all currencies on that day. If NULL, the latest available fixing is returned. Mutually exclusive with year. Default NULL.

year

(NULL | integer(1))
A calendar year, returning rates for all currencies on every working day of that year. Mutually exclusive with date. Default NULL.

lang

(character(1))
Language for the country and currency names, either "EN" or "CZ". Default "EN".

Value

A data.table::data.table() with the requested exchange rates. The rate is the amount of Czech koruna per amount units of the foreign currency.

https://api.cnb.cz/cnbapi/swagger-ui.html

See Also

Other data: banxico_data(), bbk_data(), bbk_series(), bcb_data(), bcb_expectations(), bcb_fx_rates(), bcb_inflation(), bcb_selic(), bcb_top5(), bde_data(), bde_latest(), bdf_codelist(), bdf_data(), bdf_dataset(), bdp_data(), bis_data(), boc_data(), boe_data(), boi_data(), boj_data(), cnb_czeonia(), cnb_data(), cnb_fx_other_rates(), cnb_pribor(), ecb_data(), nbp_fx_rates(), nbp_gold(), nob_data(), onb_data(), snb_data(), srb_cross_rates(), srb_data()

Examples



# latest fixing for all currencies
cnb_fx_rates()

# all fixings for a given year
cnb_fx_rates(year = 2024L)



bbk documentation built on Aug. 28, 2026, 5:07 p.m.