Skip to contents

Retrieve the available indicators and their attributes from the CNB ARAD database. Use this to discover indicator identifiers for cnb_data().

Usage

cnb_indicators(
  indicator_id = NULL,
  set_id = NULL,
  base_id = NULL,
  selection_id = NULL,
  lang = "en",
  api_key = cnb_arad_key()
)

Arguments

indicator_id

(NULL | character())
One or more indicator identifiers to retrieve (e.g. "SMV5M603"). Exactly one of indicator_id, set_id, base_id, or selection_id must be provided.

set_id

(NULL | character(1))
A set ("sestava") identifier, returning all of its indicators.

base_id

(NULL | character(1))
A base identifier, returning all of its indicators.

selection_id

(NULL | character(1))
The identifier of a named selection ("My selections") created in your ARAD account.

lang

(character(1))
Language for the textual attributes, either "en" or "cs". Default "en".

api_key

(character(1))
API key to use for the request. Defaults to the value returned by cnb_arad_key(), which reads from the CNB_ARAD_KEY environment variable.

Value

A data.table::data.table() with one row per indicator and columns including indicator_id, indicator_name, frequency_code, frequency_name, unit_mult_code, unit_mult_name, and unit.

Examples

if (FALSE) { # \dontrun{
cnb_indicators(set_id = "1058")
} # }