Retrieve metadata from the National Bank of Belgium SDMX Web Service (NBB.Stat).
Value
A data.table::data.table() with the requested metadata.
See also
Other metadata:
banxico_metadata(),
bbk_dimension(),
bbk_metadata(),
bcb_currencies(),
bdf_dimension(),
bdp_dataset(),
bdp_dimension(),
bdp_domain(),
bdp_series(),
bis_dimension(),
bis_metadata(),
boi_dimension(),
boi_metadata(),
boj_metadata(),
cnb_dimension(),
cnb_indicators(),
cnb_snapshots(),
cnb_tree(),
ecb_dimension(),
ecb_metadata(),
nbb_dimension(),
nob_dimension(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
snb_metadata(),
snb_toc(),
srb_calendar(),
srb_series()
Examples
# \donttest{
nbb_metadata("dataflow")
#> id
#> <char>
#> 1: DF_AFCSURV
#> 2: DF_AFCSURV_CREDIT
#> 3: DF_AGREED_WAGES
#> 4: DF_AMOLO
#> 5: DF_AMPORTS
#> ---
#> 191: DF_TREASURY
#> 192: DF_TREASVAR
#> 193: DF_UCIDEV
#> 194: DF_UNEMPLOYMENT
#> 195: DF_UNEMPLOY_RATE
#> name
#> <char>
#> 1: Quarterly survey on the assessment of financing conditions
#> 2: Quarterly survey on the assessment of financing conditions: Credit constraint perception
#> 3: Collectively agreed wages
#> 4: Outstanding amount of linear bonds
#> 5: Ports study
#> ---
#> 191: Treasury
#> 192: Nominal variation of the net debt and net financial balance of the Treasury
#> 193: Developments of UCIs
#> 194: Number of unemployed job-seekers - unemployement
#> 195: Harmonised unemployment rate
nbb_metadata("datastructure", "DSD_EXR")
#> id name
#> <char> <char>
#> 1: DSD_EXR EXR DSD
nbb_metadata("codelist", "CL_EXR_CURRENCY")
#> id name
#> <char> <char>
#> 1: CL_EXR_CURRENCY Currency
nbb_metadata("dataflow", "DF_EXR", lang = "fr")
#> id name
#> <char> <char>
#> 1: DF_EXR Cours de change de référence de l'euro en unités de monnaie nationale
# }