Retrieve the dimension structure for a given dataflow from the Norges Bank SDMX Web Service.
Arguments
- id
(character(1))
The id of the data structure definition to query (e.g., "NB_EXR").
Value
A data.table::data.table() with columns:
- id
The dimension id (e.g., "FREQ", "BASE_CUR")
- position
The position of the dimension in the series key
- codelist
The id of the associated codelist (e.g., "CL_FREQ")
See also
Other metadata:
bbk_dimension(),
bbk_metadata(),
bis_dimension(),
bis_metadata(),
ecb_dimension(),
ecb_metadata(),
nob_metadata(),
onb_dimension(),
onb_frequency(),
onb_hierarchy(),
onb_metadata(),
onb_toc(),
snb_dimension(),
srb_calendar(),
srb_series()
Examples
# \donttest{
nob_dimension("DSD_EXR")
#> id position codelist
#> <char> <int> <char>
#> 1: FREQ 1 CL_FREQ
#> 2: BASE_CUR 2 CL_CURRENCY
#> 3: QUOTE_CUR 3 CL_CURRENCY
#> 4: TENOR 4 CL_TENOR
# }